Function vmap::os::lock[][src]

pub unsafe fn lock(pg: *mut u8, len: usize) -> Result<()>
Locks physical pages into memory.

Safety

This does not know or care if pg or len are valid. That is, it may be null, not at a proper page boundary, point to a size different from len, or worse yet, point to a properly mapped pointer from some other allocation system.

Generally don’t use this unless you are entirely sure you are doing so correctly.