pub type ConvertResult<T, F> = Result<T, (Error, F)>;Expand description
A specialiazed Result type for conversion operations.
The origin self type is consumed When converting between Map
and MapMut types. The ConvertResult returns the original input
value on failure so that it isn’t necessarily dropped. This allows
a failure to be handled while stil maintaining the existing mapping.
Aliased Type
pub enum ConvertResult<T, F> {
Ok(T),
Err((Error, F)),
}